==> apache_airflow-2.0.1rc2-py3-none-any.whl: airflow/contrib/hooks/aws_hook.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""This module is deprecated. Please use `airflow.providers.amazon.aws.hooks.base_aws`."""

import warnings

# pylint: disable=unused-import
from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook, _parse_s3_config, boto3  # noqa

warnings.warn(
    "This module is deprecated. Please use `airflow.providers.amazon.aws.hooks.base_aws`.",
    DeprecationWarning,
    stacklevel=2,
)


class AwsHook(AwsBaseHook):
    """This class is deprecated. Please use `airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`."""

    def __init__(self, *args, **kwargs):
        warnings.warn(
            "This class is deprecated. Please use `airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`.",
            DeprecationWarning,
            stacklevel=2,
        )
        super().__init__(*args, **kwargs)

==> apache_airflow-2.2.5-py3-none-any.whl: airflow/contrib/hooks/aws_hook.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""This module is deprecated. Please use :mod:`airflow.providers.amazon.aws.hooks.base_aws`."""

import warnings

from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook, _parse_s3_config, boto3  # noqa

warnings.warn(
    "This module is deprecated. Please use `airflow.providers.amazon.aws.hooks.base_aws`.",
    DeprecationWarning,
    stacklevel=2,
)


class AwsHook(AwsBaseHook):
    """
    This class is deprecated.
    Please use :class:`airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`.
    """

    def __init__(self, *args, **kwargs):
        warnings.warn(
            "This class is deprecated. Please use `airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`.",
            DeprecationWarning,
            stacklevel=2,
        )
        super().__init__(*args, **kwargs)
